@@ -2,10 +2,10 @@ package Devel::Cover::Report::Html_subtle;
 use strict;
 use warnings;
 
-our $VERSION = "0.27";
+our $VERSION = "0.28";
 
-use Devel::Cover::DB 0.27;
-use Devel::Cover::Truth_Table 0.27;
+use Devel::Cover::DB 0.28;
+use Devel::Cover::Truth_Table 0.28;
 
 use Cwd();
 use Template 2.00;
@@ -388,7 +388,7 @@ package Devel::Cover::Report::Html_subtle::Template::Provider;
 use strict;
 use warnings;
 
-our $VERSION = "0.27";
+our $VERSION = "0.28";
 
 use base "Template::Provider";
 
@@ -406,7 +406,7 @@ sub fetch {
 $Templates{html} = <<'EOT';
 <!--
 
-This file was generated by Devel::Cover Version 0.27
+This file was generated by Devel::Cover Version 0.28
 
 Devel::Cover is copyright 2001-2002, Paul Johnson (pjcj@cpan.org)
 
@@ -700,6 +700,9 @@ $Templates{file} = <<'EOT';
 [% END %]
 EOT
 
+# remove some whitespace from templates
+s/^\s+//gm for values %Templates;
+
 1;
 
 =pod
@@ -733,7 +736,7 @@ Huh?
 
 =head1 VERSION
 
-Version 0.27 - 9th November 2003
+Version 0.28 - 1st December 2003
 
 =head1 LICENCE
 
